@@ -25,10 +25,10 @@ class BaseContext:
         self.callback_url = self.__http.build_url(f'interactions/{self.id}/{self.token}/callback')
 
     async def callback(self, content: str = '', embeds: list[Embed] = [], embed: Embed = None, components: list[ActionRow] = [], ephemeral: bool = False, _type: int = utils.CHANNEL_WITH_SOURCE):
-        if len(embeds) > 0 and embed is not None:
+        if len(list(embeds)) > 0 and embed is not None:
             _embeds = embeds.insert(0, embed)
         
-        elif embed is not None and len(embeds) == 0:
+        elif embed is not None and len(list(embeds)) == 0:
             _embeds = [embed]
 
         else:
